// Module: CalMOSCoreData
// Author: Hassan Siddiqui
//
// Description: Cal MOS Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalMOSCoreData.cc,v 1.20 2000/10/20 17:40:23 hsiddiqu Exp $

/* General */
#include <iostream>
#include <iomanip>

/* SAS-specific classes */
#include "Xmm.h"
#include "common.h"
#include "OalServer.h"
#include "CalServer.h"
#include "Tracer.h"

/* Local classes */
#include "CalMOSCoreData.h"
#include "SimpleIterator.h"
#include "NonUnifBinnedAxis.h"
#include "NullPileupCorrector.h"

/* Constructors */

CalMOSCoreData::CalMOSCoreData( Xmm::Instrument instrumentID,
				const string & datamode,
				const string & dateobs,
				const PosWCS * const poswcs,
				const string & filter,
				double psfenergy) :
  CalCoreData(psfenergy, datamode, dateobs, poswcs)
{
  errstr << "Creating CalMOSCoreData object .. "
         << filter
	 << Sas::message(Msg::App, Msg::Verbose);

  /* Set up CAL server */
  //calServer.setInstrument(instrumentID);
  calServer.state()->ccd()->set(EMOScam::CCD_1);
  calServer.state()->node()->set(EMOScam::PRIMARY_NODE);

  //calServer.state()->filter()->set(Xmm::toFilter(filter)); 

  /* Switch off randomization */
  //calServer.state()->randomize()->set(false);

  /* Initialise remaining members */
  init(instrumentID);
};

/*  Destructors  */
CalMOSCoreData::~CalMOSCoreData()
{
  PROC;
  ENDPROC;
};

unsigned CalMOSCoreData::ccdFirst() const 
{ PROC; RETURN EMOScam::CCD_FIRST; }

unsigned CalMOSCoreData::ccdLast()  const 
{ PROC; RETURN EMOScam::CCD_LAST;  } 


/** Iterator methods. */

GeneralIterator<int> * CalMOSCoreData::xpixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _emosCam.minX(), 
				    _emosCam.maxX()) );
}

GeneralIterator<int> * CalMOSCoreData::ypixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _emosCam.minY(), 
				    _emosCam.maxY()) );
}
