//
// Module: CalPsfModel
// Author: Hassan Siddiqui
//
// Description: 
//
// Wrapper class around CAL psf model.
//
// Modifications: See ChangeLog
// 
// $Id: CalPsfModel.h,v 1.2 2000/11/02 16:48:40 hsiddiqu Exp $

#ifndef CalPsfModel_H
#define CalPsfModel_H

/* SAS-specific */
#include "CalCommon.h"
#include "CalServer.h"
#include "PsfDataServer.h"
#include "Region.h"

/* Local */
#include "PsfModel.h"
#include "PositionUtils.h"
#include "CamCoords.h"
#include "TelCoords.h"

class CalPsfModel: public PsfModel
{
public:

  /*** NOTE: units for both x/y directions are 0.05 arcseconds ***/

  /* Constructor */
  CalPsfModel( double energy,
	       double xcentre,
	       double ycentre, 
               AccuracyLevel mode,
	       const PositionUtils * const putils
	       );

  /* Destructor */
  ~CalPsfModel();
  
  /* Return normalized PSF function at given position */
  double psf( double x, 
	      double y) const;
  
  /* Calculate integrated PSF over a rectangular area. */
  double int_psf( double xboxcentre, 
		  double yboxcentre, 
		  double xboxsize,
		  double yboxsize) const;

  double rad_psf() const;

  void energy(double energy);
  
  void setRadius(vector<double> radii);

  void setNgridEls(unsigned int NGridEls);

  string mode() const;

  void setBoxShape(ShapeBasics::ShapeType shape);

private:

  Psf *  _psf;
  const PositionUtils *  _putils;
  AccuracyLevel _mode;
  vector<double> _radii;
  CamCoords _offset;
  TelCoords _t;
  ShapeBasics::ShapeType _boxShape;
};

#endif
