//
// Module: CheckExpr
// Author: Hassan Siddiqui
//
// Description: 
//
// A simple tool to check whether a selection expression
// contains any entries of type "true".
//
// Modifications: See ChangeLog
// 
// $Id: CheckExpr.cc,v 1.2 2000/11/10 12:52:18 hsiddiqu Exp $


/* SAS classes */
#include "Tracer.h"
#include "errstr.h"

/* Local classes */
#include "CheckExpr.h"


bool CheckExpr::check(const string & instr)
{
  PROC;

  string str=instr;

  string::size_type left = 0;
  string::size_type right;

  bool done=false;

  while (!done)
    {
      string::size_type right1 = str.find("||");
      string::size_type right2 = str.find("&&");
      
      if (right2 < right1 || right1==string::npos)
	{
	  right=right2;
	}
      else
	{
	  right=right1;
	}

      errstr 
	<< " left="  <<left
	<< " right="  <<right
	<< " right1="  <<right1
	<< " right2="  <<right2
	<< Sas::message(Msg::App, Msg::Noisy);
      
      string token;
      
      if (right == string::npos)
	{
	  token=str;
	  done=true;
	}
      else
	{
	  
	  token=str.substr(left,right);
	  str = str.substr(right+2);
	}
      
      errstr 
	<< " token=["<< token.c_str()<<"]"
	<< " reminder=["<< str.c_str()<<"]"
	<< Sas::message(Msg::App, Msg::Noisy);

      if ( token.find("true") == string::npos )
	{
	  errstr 
	    << "The token ["<< token << "] is not true."
	    << Sas::message(Msg::App, Msg::Noisy);

	  ALTRETURNV(false);
	}
    }

  RETURN true;
}
