// 
// Module: DummyPNCoreData
// Author: Hassan Siddiqui
//
// Description: 
// Dummy PN Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: DummyPNCoreData.cc,v 1.2 2000/08/03 07:21:30 hsiddiqu Exp $

/* General */

/* SAS-specific */
#include "Xmm.h"
#include "Tracer.h"

/* Local classes */
#include "DummyPNCoreData.h"
#include "SimpleIterator.h"
#include "NonUnifBinnedAxis.h"

/*  Constructors */
DummyPNCoreData::DummyPNCoreData( Xmm::Instrument /* instrumentID */) 
    {

      _sourcePosition = new SourcePosition(0,0,0,0);

      _psf = new PsfModel (0, 0, 120, 10);

    };

  /*  Destructors */
DummyPNCoreData::~DummyPNCoreData()
{
  PROC;
  delete _psf; _psf = 0;
  delete _sourcePosition; _sourcePosition = 0;
  ENDPROC;
};
  
const BinnedAxis * DummyPNCoreData::ebins() const
{
  PROC;
  IntervalVector<double> iv;
  iv.push_back(Bin(0, 15));
  RETURN new NonUnifBinnedAxis(iv);
}

void DummyPNCoreData::setCcd(const CamCoords & /* camcoords */)
{
  PROC;
  RETURN true;
}

unsigned int DummyPNCoreData::ccdFirst() const {PROC; RETURN 1;}
unsigned int DummyPNCoreData::ccdLast() const {PROC; RETURN 1;}


/* Return source position */
const SourcePosition * DummyPNCoreData::sourcePosition() const
{ PROC; RETURN _sourcePosition; }

const PsfModel * DummyPNCoreData::psf() const
{ PROC; RETURN _psf; }

/* Convert from DETX/DETY (0.05 arcsec units) to camcoord2 */
const CamCoords DummyPNCoreData::detxy005ToCamCoord2( 
						      int /* detx_005 */, 
						      int /* dety_005 */) const
{
  PROC;
  RETURN CamCoords( 0, 0, 0);
}

/* Convert from CAMCOORD2 to PIXCOORD */
const PixCoords DummyPNCoreData::camCoord2ToPixCoord( const CamCoords & /* camcoords */ ) const
{
  PROC;
  RETURN PixCoords( 0, 0 );
}

/* Pixel size, in arcsecs */
double DummyPNCoreData::pixelSize()          const
{
  PROC;
  RETURN 1.0;
};

/* Frame period, in seconds */
double DummyPNCoreData::framePeriod()          const
{
  PROC;
  RETURN 1.0;
};


/* Iterator methods. */

GeneralIterator<int> * DummyPNCoreData::ccdIterator()
{
  PROC;
  const int CCD_FIRST  = 0;
  const int CCD_LAST   = 6;
  RETURN (new SimpleIterator<int>(CCD_FIRST, CCD_LAST));
}

GeneralIterator<int> * DummyPNCoreData::xpixelIterator() const
{
  PROC;
  const int X_PIXEL_LOW  = 0;
  const int X_PIXEL_HIGH = 10;
  RETURN (new SimpleIterator<int>(X_PIXEL_LOW, X_PIXEL_HIGH));
}

GeneralIterator<int> * DummyPNCoreData::ypixelIterator() const
{
  PROC;
  const int Y_PIXEL_LOW  = 0;
  const int Y_PIXEL_HIGH = 10;
  RETURN (new SimpleIterator<int>(Y_PIXEL_LOW, Y_PIXEL_HIGH));
}

/* Data resource methods */

/* Mirror area, in cm2 */
double DummyPNCoreData::effectiveArea      (double /* energy */) const
{
  PROC;
  RETURN 3000.0;
}

  double DummyPNCoreData::quantumEfficiency  (double /* x */, 
					       double /* y */, 
					       double /* energy */) const
{
  PROC;
  RETURN 1.;
}

double DummyPNCoreData::filterTransmission (double /* x */, 
					     double /* y */, 
					     double /* energy */) const
{
  PROC;
  RETURN 1.;
}

double DummyPNCoreData::gratingAttenuation( double /* energy */) const
{
  PROC;
  RETURN 1.;
}
