// Module: PosWCS
//
// Author: Hassan Siddiqui
//
// Description: 
//
// Reads in X/Y WCS from a given dataset.
//
// If the info in invalid/not present, 
// the valid() method will return false.
//
// Modifications: See ChangeLog
// 
// $Id: PosWCS.h,v 1.1 2000/10/20 17:40:24 hsiddiqu Exp $

#ifndef PosWCS_H
#define PosWCS_H

/* SAS-specific */
#include "Dal.h"

/* Local classes */
#include "WCSConvertor.h"


class PosWCS
{
public:

  /* Read state from dataset */
  PosWCS( const DataSet * const set,
	  double default_ra,
	  double default_dec,
          double refpa,
          bool useodf );

  /* Destructor */
 ~ PosWCS();

  /* Returns a pointer to WCS object */
  const WCSConvertor * const wcs() const;

  /* Returns the input position angle */
  const double PosWCS::pa() const;

  /* Returns whether to use the ODF for attitude reconstruction */
  const bool PosWCS::useODF() const;

private:

  bool _valid;

  double _refpa;

  bool _useodf;

  const WCSConvertor * _wcs;
};

#endif
