//
// Module: RegionExtent
// Author: Hassan Siddiqui
//
// Description: 
//
// Class to determine the DSS region extents in
// X/Y and DETX/Y
//
// Modifications: See ChangeLog
// 
// $Id: RegionExtent.h,v 1.1 2000/11/10 12:53:11 hsiddiqu Exp $

#ifndef RegionExtent_H
#define RegionExtent_H

/* SAS */
#include "dss.h"
#include "Xmm.h"

/* Local */
#include "PositionUtils.h"
#include "PosWCS.h"

class RegionExtent
{
public:
  
  /* Construct object given explicit extent */
  RegionExtent( double xmin,
		double xmax,
		double ymin,
		double ymax );

  /* Construct object based given a DataSubspace and CoreData object */
  RegionExtent( DataSubspace * dss,
                PositionUtils * putils, const string & datamode,
                const string & dateobs, const PosWCS * const poswcs );

  /* Check if object is constructed correctly */
  bool isValid() const;

  /* Report if extent is larger than specified bounds */
  void checkBounds( double boundsxmin,
		    double boundsxmax,
		    double boundsymin,
		    double boundsymax) const;

  /* Accessors */

  double xmin() const;
  double xmax() const;
  double ymin() const;
  double ymax() const;

private:

  /* Suppress default constructor */
  RegionExtent();

  bool _isValid;

  double _xmin;
  double _xmax;
  double _ymin;
  double _ymax;
};

#endif
