//
// Module: RmfEbins
// Author: Hassan Siddiqui
//
// Description: 
//
// Factory for generating a BinnedAxis object 
// from ebins component of an rmf dataset
//
// Modifications: See ChangeLog
// 
// $Id: RmfEbins.cc,v 1.3 2001/03/20 16:55:03 hsiddiqu Exp $

/* General */

/* SAS-specific */
#include "Dal.h"
#include "Tracer.h"

/* Local */
#include "RmfEbins.h"
#include "NonUnifBinnedAxis.h"

/* Constructor */
RmfEbins::RmfEbins()
{ 
  PROC;
  ENDPROC;
}

BinnedAxis * RmfEbins::ebins( const string & setname )
{
  PROC;

  IntervalVector<double> intervalvector;

  DataSet * set = dataSetServer->open( setname, DataSet::Read );

  Table * table = 0;

  if ( set->hasBlock("MATRIX") )
    {
      table = set->table("MATRIX");
    }
  else if ( set->hasBlock("SPECRESP MATRIX") )
    {
      table = set->table("SPECRESP MATRIX");
    }
  else
    {
      errstr 
	<< "There is no table of name 'MATRIX' or 'SPECRESP MATRIX' in dataset " << setname
	<< Sas::error("NoRmfTablePresent");
    }

  Column * elowCol  = table->column("ENERG_LO");
  Column * ehighCol = table->column("ENERG_HI");

  for (unsigned row = 0; row < table->rows(); ++row)
    {
      ColumnData * elowColData  = elowCol->data(row, 1); 
      ColumnData * ehighColData = ehighCol->data(row, 1);

      Interval<double> ebins(elowColData->real32Data()[0] * 1000., 
			     ehighColData->real32Data()[0] * 1000.);
      
      intervalvector.push_back(ebins);

      delete ehighColData;
      delete elowColData;

    }

  dataSetServer->close(set);

  NonUnifBinnedAxis *nub = new NonUnifBinnedAxis(intervalvector);

  RETURN nub;
}

/* Destructor */
RmfEbins::~RmfEbins()
{
  PROC;
  ENDPROC;
}
